﻿using Hotline.FlowEngine;
using Hotline.FlowEngine.Definitions;
using Hotline.FlowEngine.Workflows;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Enums.FlowEngine;

namespace Hotline.Application.FlowEngine
{
    public interface IWorkflowApplication
    {
        Task StartWorkflowAsync(StartWorkflowDto dto, string? externalId = null, CancellationToken cancellationToken = default);

        /// <summary>
        /// 流转至下一节点（节点办理）
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task NextAsync(NextWorkflowDto dto, CancellationToken cancellationToken);

        /// <summary>
        /// 查询流程下一节点配置参数
        /// </summary>
        Task<IReadOnlyList<NextStepOptions>> GetNextStepOptionsAsync(Workflow workflow, CancellationToken cancellationToken);
        Task<IReadOnlyList<NextStepOptions>> GetStartOptionsAsync(string moduleCode, CancellationToken cancellationToken);
        
        /// <summary>
        /// 撤回至任意节点
        /// </summary>
        Task RecallAsync(RecallDto dto, CancellationToken cancellationToken);

        /// <summary>
        /// 跳转至任意节点
        /// </summary>
        Task JumpAsync(RecallDto dto, CancellationToken cancellationToken);
    }
}
